@@ -1,21 +1,7 @@
 /*
-    Copyright 2013-2018 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2013-2018 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #ifndef PLASMA_NM_NETWORK_MODEL_H
@@ -27,9 +13,9 @@
 #include "networkitemslist.h"
 
 #include <NetworkManagerQt/Manager>
+#include <NetworkManagerQt/Utils>
 #include <NetworkManagerQt/VpnConnection>
 #include <NetworkManagerQt/WirelessDevice>
-#include <NetworkManagerQt/Utils>
 
 #if WITH_MODEMMANAGER_SUPPORT
 #include <ModemManagerQt/modem.h>
@@ -37,7 +23,7 @@
 
 class Q_DECL_EXPORT NetworkModel : public QAbstractListModel
 {
-Q_OBJECT
+    Q_OBJECT
 public:
     // HACK: Delay model updates to prevent jumping password entry in the applet
     // BUG: 435430
@@ -74,15 +60,11 @@ public:
         VpnState,
         VpnType,
         RxBytesRole,
-        TxBytesRole
+        TxBytesRole,
     };
     Q_ENUMS(ItemRole)
 
-    enum ModelChangeType {
-        ItemAdded,
-        ItemRemoved,
-        ItemPropertyChanged
-    };
+    enum ModelChangeType { ItemAdded, ItemRemoved, ItemPropertyChanged };
 
     int rowCount(const QModelIndex &parent) const override;
     QVariant data(const QModelIndex &index, int role) const override;
@@ -98,7 +80,7 @@ private Q_SLOTS:
     void activeConnectionAdded(const QString &activeConnection);
     void activeConnectionRemoved(const QString &activeConnection);
     void activeConnectionStateChanged(NetworkManager::ActiveConnection::State state);
-    void activeVpnConnectionStateChanged(NetworkManager::VpnConnection::State state,NetworkManager::VpnConnection::StateChangeReason reason);
+    void activeVpnConnectionStateChanged(NetworkManager::VpnConnection::State state, NetworkManager::VpnConnection::StateChangeReason reason);
     void availableConnectionAppeared(const QString &connection);
     void availableConnectionDisappeared(const QString &connection);
     void connectionAdded(const QString &connection);
@@ -121,10 +103,11 @@ private Q_SLOTS:
     void wirelessNetworkReferenceApChanged(const QString &accessPoint);
 
     void initialize();
+
 private:
     bool m_delayModelUpdates = false;
     NetworkItemsList m_list;
-    QQueue<QPair<ModelChangeType, NetworkModelItem*> > m_updateQueue;
+    QQueue<QPair<ModelChangeType, NetworkModelItem *>> m_updateQueue;
 
     void addActiveConnection(const NetworkManager::ActiveConnection::Ptr &activeConnection);
     void addAvailableConnection(const QString &connection, const NetworkManager::Device::Ptr &device);
@@ -137,7 +120,8 @@ private:
     void initializeSignals(const NetworkManager::Connection::Ptr &connection);
     void initializeSignals(const NetworkManager::Device::Ptr &device);
     void initializeSignals(const NetworkManager::WirelessNetwork::Ptr &network);
-    void updateFromWirelessNetwork(NetworkModelItem *item, const NetworkManager::WirelessNetwork::Ptr &network, const NetworkManager::WirelessDevice::Ptr &device);
+    void
+    updateFromWirelessNetwork(NetworkModelItem *item, const NetworkManager::WirelessNetwork::Ptr &network, const NetworkManager::WirelessDevice::Ptr &device);
 
     void insertItem(NetworkModelItem *item);
     void removeItem(NetworkModelItem *item);
